@@ -1,9 +1,14 @@
 # -*- coding: utf-8 -*-
 
+import pytzdata
+
 from .timezone import Timezone, FixedTimezone, UTC
 from .local_timezone import LocalTimezone
 
 
+timezones = pytzdata.timezones
+
+
 def timezone(name):
     """
     Loads a Timezone instance by name.
